package com.community.huiju.controller;

import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.common.base.BaseController;
import com.community.huiju.service.ITaUserVerifyService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpSession;

@RestController
@RefreshScope
@RequestMapping("/")
@Api(value = "审核用户API", description = "审核用户API")
public class UserVerifyController extends BaseController {

    @Autowired
    private ITaUserVerifyService iTaUserVerifyService;

    @RequestMapping(value = "/user/verify/all", method = RequestMethod.GET)
    @ApiOperation(value = "获取待审核的用户列表", notes = "获取待审核的用户列表")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "phone", value = "手机号"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "userName", value = "用户名"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "idCard", value = "身份证"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "pageNum", value = "第几页"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "pageSize", value = "一页多少行"),
    })
    public ResponseBean getAll(@RequestParam(value = "phone", required = false) String phone,
                               @RequestParam(value = "userName", required = false) String userName,
                               @RequestParam(value = "idCard", required = false) String idCard,
                               @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                               @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {

        ResponseBean responseBean = new ResponseBean();
        responseBean = iTaUserVerifyService.selectAll(phone, userName, idCard, pageNum, pageSize);
        return responseBean;
    }

    @RequestMapping(value = "/user/verify/audit/{userVerifyId}", method = RequestMethod.PUT)
    @ApiOperation(value = "审核用户", notes = "审核用户")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "header", dataTypeClass = String.class, name = "X-Auth-Token", value = "token"),
            @ApiImplicitParam(paramType = "path", dataTypeClass = String.class, name = "userVerifyId", value = "审核id"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = Boolean.class, name = "verifyStatus", value = "true通过；false不通过"),
    })
    public ResponseBean getAll(@PathVariable("userVerifyId") Integer userVerifyId,
                               @RequestParam("verifyStatus") Boolean verifyStatus,
                               HttpSession session) {

        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = getUserElement(session);
        responseBean = iTaUserVerifyService.auditUser(userElement, userVerifyId, verifyStatus);
        return responseBean;
    }

}
